@@ -3,18 +3,19 @@
 
 #include "../vec.h"
 #include "../m.h"
+#include "../cov.h"
 
 namespace cec {
-
     class model {
     public:
         explicit model() = default;
+
         virtual ~model() = default;
 
-        virtual double cross_entropy(const mat &cov) const noexcept = 0;
+        virtual double cross_entropy(const covariance &cov) const noexcept = 0;
 
-        inline double energy(const mat &cov, int card, int m) const noexcept {
-            double p = card / (double) m;
+        inline double energy(const covariance &cov, int m) const noexcept {
+            double p = cov.card() / (double) m;
             return p * (-m::log(p) + cross_entropy(cov));
         }
     };
